# Intrinsic rate of increase (r) by simulation estimator. Written by James Bull 2017

# Clear everything

rm(list=ls())

# Set working directory. Wherever the data file is located

setwd()

# Import data

data <- read.table("Bull_et_al_2018_DaphniaMetalsMA_SupFile2_LH_data.csv",sep=",",header=T)

# Recode relevant variables as numeric (dataset contains NAs which are imported as text by R)

data$C1_AGE <- as.numeric(as.character(data$C1_AGE))
data$C2_AGE <- as.numeric(as.character(data$C2_AGE))
data$C3_AGE <- as.numeric(as.character(data$C3_AGE))
data$C4_AGE <- as.numeric(as.character(data$C4_AGE))
data$C1_COUNT <- as.numeric(as.character(data$C1_COUNT))
data$C2_COUNT <- as.numeric(as.character(data$C2_COUNT))
data$C3_COUNT <- as.numeric(as.character(data$C3_COUNT))
data$C4_COUNT <- as.numeric(as.character(data$C4_COUNT))
data$LONGEVITY <- as.numeric(as.character(data$LONGEVITY))

# Create lines summary table to output values to

LINE <- levels(data$LINE)
TREATMENT <- c(rep("Control",10), rep("Copper",10), rep("NickelCopper",10), rep("Competative", 10))
SUMMARY_LINES <- data.frame(LINE)
SUMMARY_LINES$TREATMENT <- TREATMENT
SUMMARY_LINES$R <- rep(NA,40)
rm(TREATMENT)

# Below is the actual model. Note: For four MA lines, this gives no output because of missing values.
# In the actual analyses these missing values were replaced with the mean of measurements of other replicates within that MA line

count2<-1

# Subset for only the data relevant to the MA line we are analysing

for(line in LINE){
  trial <- subset(data,subset=LINE==line)

# Calculate life-history table
  
max_long <- max(trial$LONGEVITY,na.rm=TRUE)
timeline <- 1:max_long
survival <- rep(1,max_long)
reproduction <- rep(0,max_long)

count <- 1
for(i in trial$C1_AGE){
  reproduction[i] <- reproduction[i] + (1/length(trial$C1_AGE[!is.na(trial$C1_AGE)]) * trial$C1_COUNT[count])
  count <- count + 1
}

count <- 1
for(i in trial$C2_AGE){
  reproduction[i] <- reproduction[i] + (1/length(trial$C2_AGE[!is.na(trial$C2_AGE)]) * trial$C2_COUNT[count])
  count <- count + 1
}

count <- 1
for(i in trial$C3_AGE){
  reproduction[i] <- reproduction[i] + (1/length(trial$C3_AGE[!is.na(trial$C3_AGE)]) * trial$C3_COUNT[count])
  count <- count + 1
}

count <- 1
for(i in trial$C4_AGE){
  reproduction[i] <- reproduction[i] + (1/length(trial$C4_AGE[!is.na(trial$C4_AGE)]) * trial$C4_COUNT[count])
  count <- count + 1
}

for(i in trial$LONGEVITY){
  survival[i] <- survival[i] - 1/length(trial$LONGEVITY[!is.na(trial$LONGEVITY)])
}

survival[3] <- sum(as.numeric(trial$ST_START=="1"))/sum(as.numeric(trial$START=="Yes"))

# Set number of days model will run for

days <- 1500

# Run model

for(d in 1:days){
  
  if(d == 1){
    pop <- c(1,rep(0,max_long-1))
    pop_days <- 1
    pop_size <- 1
  
  }else{
    
    pop_new <- c(0,(pop*survival)[1:max_long-1])
    
    pop_new[1] <- sum(pop*reproduction)

    pop_days <- c(pop_days,d)
    
    pop_size <- c(pop_size,sum(pop_new))
    
    pop <- pop_new
    
    rm(pop_new)
    
  } # closes else bracket
  
  pop_r <<- pop_size[2:days] / pop_size[1:days-1]
  
  final_r <<- mean(pop_r[(days-1-max_long):days-1])  
  
} # closes for-loop

SUMMARY_LINES$R[count2] <- final_r

count2 <- count2 + 1

plot(pop_r,ylim=c(1.0,2.0))

# Pause to allow user to check for convergence

readline("Next:")

}

# The dataframe SUMMARY_LINES will contain the output
